pub struct OutputLayerDescription<F: Field> {
pub mle: MleDescription<F>,
is_zero: bool,
}Expand description
The circuit description type for the defaul Output Layer consisting of an MLE.
Fields
mle: MleDescription<F>The metadata of this MLE: indices and associated layer.
is_zero: boolWhether this is an MLE that is supposed to evaluate to zero.
Implementations
Sourceimpl<F: Field> OutputLayerDescription<F>
impl<F: Field> OutputLayerDescription<F>
Sourcepub fn new_dense(_layer_id: LayerId, _mle_indices: &[MleIndex<F>]) -> Self
pub fn new_dense(_layer_id: LayerId, _mle_indices: &[MleIndex<F>]) -> Self
Generate an output layer containing a verifier equivalent of a
DenseMle, with a given layer_id and mle_indices.
Sourcepub fn new_zero(layer_id: LayerId, mle_indices: &[MleIndex<F>]) -> Self
pub fn new_zero(layer_id: LayerId, mle_indices: &[MleIndex<F>]) -> Self
Generate an output layer containing a verifier equivalent of a
ZeroMle, with a given layer_id and mle_indices.
Sourcepub fn is_zero(&self) -> bool
pub fn is_zero(&self) -> bool
Determine whether the MLE Output layer contains an MLE whose coefficients are all 0.
Sourcepub fn index_mle_indices(&mut self, start_index: usize)
pub fn index_mle_indices(&mut self, start_index: usize)
Label the MLE indices in this layer, starting from the start_index.
Sourcepub fn into_prover_output_layer(
&self,
circuit_map: &CircuitEvalMap<F>,
) -> OutputLayer<F>
pub fn into_prover_output_layer( &self, circuit_map: &CircuitEvalMap<F>, ) -> OutputLayer<F>
Convert this into the prover view of an output layer, using the CircuitEvalMap.
Sourceimpl<F: Field> OutputLayerDescription<F>
impl<F: Field> OutputLayerDescription<F>
Sourcepub fn layer_id(&self) -> LayerId
pub fn layer_id(&self) -> LayerId
Returns the LayerId of the intermediate/input layer that his output layer is associated with.
Sourcepub fn retrieve_mle_from_transcript_and_fix_layer(
&self,
transcript_reader: &mut impl VerifierTranscript<F>,
) -> Result<VerifierOutputLayer<F>>
pub fn retrieve_mle_from_transcript_and_fix_layer( &self, transcript_reader: &mut impl VerifierTranscript<F>, ) -> Result<VerifierOutputLayer<F>>
Retrieve the MLE evaluations from the transcript and fix the variables of this output layer to random challenges sampled from the transcript. Returns a description of the layer ready to be used by the verifier.